Device class

Constructors

Device({required bool isTablet, required bool isPhone, required bool isIos, required bool isAndroid, required bool isIphoneX, required bool hasNotch})
Device.get()
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
hasNotch bool
final
isAndroid bool
final
isIos bool
final
isIphoneX bool
final
isPhone bool
final
isTablet bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

devicePixelRatio double
getter/setter pair
height double
getter/setter pair
onMetricsChange Function?
getter/setter pair
screenHeight double
getter/setter pair
screenSize Size
getter/setter pair
screenWidth double
getter/setter pair
size Size
getter/setter pair
width double
getter/setter pair